static DH *get_dh512(void)
{
    static unsigned char dhp_512[] = {
        0x80, 0x87, 0xD3, 0xC7, 0x16, 0xE6, 0x99, 0x25, 0x74, 0x11,
        0xBF, 0x61, 0xF0, 0xB4, 0xFC, 0x10, 0xC9, 0xFD, 0x88, 0xD3,
        0x22, 0x86, 0x56, 0xDB, 0x3F, 0xD8, 0x64, 0x02, 0x0C, 0x4C,
        0x3A, 0x8C, 0x65, 0xE3, 0x19, 0x76, 0x65, 0xC1, 0xB9, 0x38,
        0x0F, 0x35, 0x34, 0xB8, 0x7D, 0x4E, 0xF9, 0xEA, 0xE4, 0x3B,
        0x67, 0x76, 0x19, 0x53, 0xA3, 0xF8, 0x6F, 0x42, 0x26, 0x58,
        0x0B, 0x70, 0x6E, 0xDB
    };
    static unsigned char dhg_512[] = {
        0x05
    };
    DH *dh = DH_new();
    BIGNUM *p, *g;

    if (dh == NULL)
        return NULL;
    p = BN_bin2bn(dhp_512, sizeof(dhp_512), NULL);
    g = BN_bin2bn(dhg_512, sizeof(dhg_512), NULL);
    if (p == NULL || g == NULL
            || !DH_set0_pqg(dh, p, NULL, g)) {
        DH_free(dh);
        BN_free(p);
        BN_free(g);
        return NULL;
    }
    return dh;
}
static DH *get_dh2048(void)
{
    static unsigned char dhp_2048[] = {
        0x89, 0xF7, 0x8E, 0x6E, 0xDF, 0x6B, 0x6D, 0x88, 0x60, 0xC7,
        0xB1, 0x50, 0xFA, 0x03, 0x19, 0x1A, 0x0E, 0xFE, 0xE2, 0x2C,
        0x58, 0x79, 0xD8, 0x89, 0x4E, 0x80, 0x94, 0xAE, 0xBC, 0x6C,
        0x79, 0xEF, 0x4F, 0x74, 0xEC, 0xBC, 0xB9, 0x0A, 0xE8, 0x8B,
        0x02, 0xDE, 0x91, 0x19, 0x80, 0x40, 0x5F, 0x89, 0xB4, 0xA7,
        0x04, 0x4F, 0x72, 0xE4, 0xF6, 0xB0, 0x0F, 0x42, 0x45, 0x57,
        0x7D, 0x48, 0x27, 0x13, 0xD7, 0x8B, 0x1A, 0x3A, 0x3F, 0x2D,
        0x61, 0x39, 0x49, 0x75, 0x4C, 0x26, 0x65, 0x9D, 0x6D, 0x41,
        0x22, 0x2F, 0xF2, 0x6B, 0x1C, 0x1B, 0x84, 0x57, 0xD9, 0x9B,
        0xEA, 0x89, 0x97, 0xCB, 0x4C, 0xD1, 0x27, 0xDD, 0x8B, 0xB6,
        0x45, 0x8C, 0x31, 0x87, 0xE1, 0x92, 0x96, 0x1F, 0xFF, 0x1C,
        0xFE, 0x71, 0xD5, 0x65, 0x15, 0x9B, 0x87, 0x5C, 0x2E, 0xE9,
        0xF8, 0x92, 0x73, 0x30, 0x66, 0xE0, 0xF6, 0x5D, 0x89, 0x97,
        0x88, 0x77, 0x00, 0x12, 0xD0, 0x93, 0xDA, 0x49, 0x12, 0xDC,
        0xED, 0x0E, 0xDD, 0x3B, 0x89, 0x33, 0xE8, 0xE9, 0x81, 0x5A,
        0x5B, 0xB4, 0x77, 0xA6, 0xBA, 0x2B, 0xF3, 0xA5, 0xFE, 0x0C,
        0x8A, 0x9F, 0xCB, 0xFF, 0x72, 0x85, 0x42, 0xA3, 0xFB, 0x5C,
        0xDF, 0x97, 0x43, 0x16, 0xF3, 0x5C, 0x1F, 0x20, 0x08, 0x69,
        0x29, 0x44, 0xF6, 0xE7, 0xC0, 0x7F, 0x9D, 0x89, 0x74, 0xF9,
        0xFC, 0x97, 0xA7, 0xE4, 0x28, 0x9D, 0xF2, 0x35, 0x15, 0x0C,
        0x4B, 0x55, 0xE5, 0xA4, 0x85, 0x14, 0x02, 0xC1, 0xE0, 0x17,
        0x34, 0x26, 0x41, 0xAE, 0x27, 0x79, 0xBC, 0x13, 0x67, 0x08,
        0x6E, 0x66, 0x4A, 0xF1, 0xA3, 0xF4, 0x53, 0x5C, 0xEC, 0xF0,
        0x97, 0x34, 0x26, 0x62, 0xD8, 0x16, 0x1D, 0x6A, 0x80, 0xA2,
        0x0F, 0x6D, 0x3D, 0x3F, 0xB6, 0x8C, 0xEE, 0x7F, 0xAF, 0xFC,
        0xAB, 0x66, 0xB3, 0xC7, 0x59, 0xAB
    };
    static unsigned char dhg_2048[] = {
        0x05
    };
    DH *dh = DH_new();
    BIGNUM *p, *g;

    if (dh == NULL)
        return NULL;
    p = BN_bin2bn(dhp_2048, sizeof(dhp_2048), NULL);
    g = BN_bin2bn(dhg_2048, sizeof(dhg_2048), NULL);
    if (p == NULL || g == NULL
            || !DH_set0_pqg(dh, p, NULL, g)) {
        DH_free(dh);
        BN_free(p);
        BN_free(g);
        return NULL;
    }
    return dh;
}
